import { Component, EventEmitter, Injectable, Input, NgModule, Output } from '@angular/core';
import { CommonModule } from '@angular/common';
import { FormBuilder, ReactiveFormsModule } from '@angular/forms';
import 'rxjs/add/operator/takeWhile';
var FormService = (function () {
    /**
     * @param {?} formBuilder
     */
    function FormService(formBuilder) {
        this.formBuilder = formBuilder;
    }
    /**
     * @param {?} controlsConfig
     * @return {?}
     */
    FormService.prototype.createForm = function (controlsConfig) {
        return this.formBuilder.group(controlsConfig);
    };
    /**
     * @param {?} formGroup
     * @param {?} formErrors
     * @param {?=} data
     * @return {?}
     */
    FormService.prototype.onValueChanged = function (formGroup, formErrors, data) {
        if (!formGroup) {
            return;
        }
        var /** @type {?} */ form = formGroup;
        for (var /** @type {?} */ field in formErrors) {
            // clear previous error message (if any)
            formErrors[field] = '';
            var /** @type {?} */ control = form.get(field);
            if (control && control.dirty && !control.valid) {
                var /** @type {?} */ messages = this.validationMessages[field];
                for (var /** @type {?} */ key in control.errors) {
                    formErrors[field] += messages[key] + ' ';
                }
            }
        }
    };
    /**
     * @param {?} validationMessages
     * @return {?}
     */
    FormService.prototype.setValidationMessages = function (validationMessages) {
        this.validationMessages = validationMessages;
    };
    return FormService;
}());
FormService.decorators = [
    { type: Injectable },
];
/**
 * @nocollapse
 */
FormService.ctorParameters = function () { return [
    { type: FormBuilder, },
]; };
var LoginComponent = (function () {
    /**
     * @param {?} formBuilder
     * @param {?} formService
     */
    function LoginComponent(formBuilder, formService) {
        this.formBuilder = formBuilder;
        this.formService = formService;
        this.onLoginSubmit = new EventEmitter();
        this.formErrors = {
            'username': '',
            'password': ''
        };
    }
    /**
     * @return {?}
     */
    LoginComponent.prototype.ngOnInit = function () {
        this.createForm();
    };
    /**
     * @return {?}
     */
    LoginComponent.prototype.onLogin = function () {
        var /** @type {?} */ formModel = this.loginForm.value;
        var /** @type {?} */ username = (formModel.username);
        var /** @type {?} */ password = (formModel.password);
        this.onLoginSubmit.emit({
            'username': username,
            'password': password
        });
    };
    /**
     * @return {?}
     */
    LoginComponent.prototype.createForm = function () {
        var _this = this;
        console.log(this.validationMethodPassword);
        console.log(this.validationMethodUsername);
        console.log(this.validationMsgLogin);
        this.loginForm = this.formService.createForm({
            username: ['', this.validationMethodUsername],
            password: ['', this.validationMethodPassword]
        });
        this.formService.setValidationMessages(this.validationMsgLogin);
        this.loginForm.valueChanges
            .subscribe(function (data) { return _this.formService.onValueChanged(_this.loginForm, _this.formErrors, data); });
    };
    return LoginComponent;
}());
LoginComponent.decorators = [
    { type: Component, args: [{
                selector: 'login',
                template: "\n    <form id=\"loginForm\" [formGroup]=\"loginForm\" (ngSubmit)=\"onLogin()\" class=\"form-horizontal\">\n      <div id=\"div-login-error\" *ngIf=\"errorMessage\" class=\"alert alert-danger\" role=\"alert\">\n        {{ errorMessage }}\n      </div>\n      <hr>\n      <div class=\"form-group\">\n        <label id=\"label-username\" for=\"input-username\" class=\"col-md-3 control-label \">\u0E0A\u0E37\u0E48\u0E2D\u0E1C\u0E39\u0E49\u0E43\u0E0A\u0E49\u0E07\u0E32\u0E19</label>\n        <div class=\"col-md-9\">\n          <input id=\"input-username\" type=\"text\" formControlName=\"username\" class=\"form-control  text-center\"  placeholder=\"username\">\n          <span id=\"span-username-error\" class=\"validate-msg\" *ngIf=\"formErrors.username\">\n              {{ formErrors.username }}\n            </span>\n        </div>\n      </div>\n      <div class=\"form-group\">\n        <label id=\"label-password\" for=\"input-password\" class=\"col-md-3 control-label \">\u0E23\u0E2B\u0E31\u0E2A\u0E1C\u0E48\u0E32\u0E19</label>\n        <div class=\"col-md-9\">\n          <input id=\"input-password\" type=\"password\" formControlName=\"password\" class=\"form-control text-center\" placeholder=\"password\">\n          <span id=\"span-password-error\" class=\"validate-msg\" *ngIf=\"formErrors.password\">\n              {{ formErrors.password }}\n            </span>\n        </div>\n      </div>\n      <div class=\"form-group\">\n        <label class=\"col-md-3 control-label\"></label>\n        <div class=\"col-md-9\">\n          <input id=\"btn-login\" type=\"submit\" class=\"btn btn-submit \" value=\"LOG IN\" [disabled]=\"!loginForm.valid\">\n        </div>\n      </div>\n    </form>\n  ",
                styles: ["\n    .control-label {\n        color:#4d6513;\n    }\n    .btn{ \n        min-width: 100%;\n        white-space: normal;\n     }\n    hr {\n        margin-top: 0px;\n    }\n  "],
                providers: [
                    FormService
                ]
            },] },
];
/**
 * @nocollapse
 */
LoginComponent.ctorParameters = function () { return [
    { type: FormBuilder, },
    { type: FormService, },
]; };
LoginComponent.propDecorators = {
    'validationMethodUsername': [{ type: Input },],
    'validationMethodPassword': [{ type: Input },],
    'validationMsgLogin': [{ type: Input },],
    'onLoginSubmit': [{ type: Output },],
};
var OtpComponent = (function () {
    /**
     * @param {?} formBuilder
     * @param {?} formService
     */
    function OtpComponent(formBuilder, formService) {
        this.formBuilder = formBuilder;
        this.formService = formService;
        this.onOtpSubmit = new EventEmitter();
        this.onOtpCancel = new EventEmitter();
        this.formErrors = {
            'otp': ''
        };
        this.alive = true;
    }
    /**
     * @return {?}
     */
    OtpComponent.prototype.ngOnInit = function () {
        this.createForm();
    };
    /**
     * @return {?}
     */
    OtpComponent.prototype.onCheckOtp = function () {
        var /** @type {?} */ formModel = this.otpForm.value;
        var /** @type {?} */ otp = (formModel.otp);
        this.onOtpSubmit.emit(otp);
    };
    /**
     * @return {?}
     */
    OtpComponent.prototype.onCancleOtp = function () {
    };
    /**
     * @return {?}
     */
    OtpComponent.prototype.createForm = function () {
        var _this = this;
        this.otpForm = this.formService.createForm({
            otp: ['', this.validationMethodOtp]
        });
        this.formService.setValidationMessages(this.validationMsgOtp);
        this.otpForm.valueChanges
            .subscribe(function (data) { return _this.formService.onValueChanged(_this.otpForm, _this.formErrors, data); });
    };
    return OtpComponent;
}());
OtpComponent.decorators = [
    { type: Component, args: [{
                selector: 'otp',
                template: "\n    <form id=\"otpform\" class=\"form-horizontal\" [formGroup]=\"otpForm\" (ngSubmit)=\"onCheckOtp()\">\n        <div id=\"div-otp-error\" *ngIf=\"errorMessage\" class=\"alert alert-danger\" role=\"alert\">\n            {{ errorMessage }}\n        </div>\n        <hr>\n        <div class=\"form-group\">\n            <div class=\"col-md-offset-3 col-md-9\">\n                <p class=\"validate-msg\">\u0E01\u0E23\u0E38\u0E13\u0E32\u0E43\u0E2A\u0E48\u0E23\u0E2B\u0E31\u0E2A\u0E1C\u0E48\u0E32\u0E19\u0E17\u0E35\u0E48\u0E44\u0E14\u0E49\u0E23\u0E31\u0E1A\u0E17\u0E32\u0E07 SMS \u0E40\u0E1E\u0E37\u0E48\u0E2D\u0E40\u0E02\u0E49\u0E32\u0E2A\u0E39\u0E48\u0E23\u0E30\u0E1A\u0E1A</p>\n            </div>\n            <label id=\"label-otp\" for=\"input-otp\" class=\"col-md-3 control-label\">OTP</label>\n            <div class=\"col-md-9\">\n                <input id=\"input-otp\" type=\"text\" formControlName=\"otp\" class=\"form-control text-center\" placeholder=\"OTP\" >\n                <span id=\"span-otp-error\" class=\"validate-msg\" *ngIf=\"formErrors.otp\">{{formErrors.otp}}</span>\n            </div>\n        </div>\n        <div class=\"form-group\">\n            <div class=\"col-md-offset-3 col-md-9\">\n                <button id=\"btn-otp-ok\" type=\"submit\" class=\"btn btn-submit\" data-toggle=\"modal\" data-target=\".bs-example-modal-sm\" [disabled]=\"!otpForm.valid\">OK</button>\n                <button id=\"btn-otp-cancel\" type=\"button\" class=\"btn btn-cancel\" (click)=\"onCancleOtp()\">Cancel</button>\n            </div>\n        </div>\n    </form>\n  ",
                styles: ["\n    .control-label {\n        color:#4d6513;\n    }\n    button.btn.btn-cancel, button.btn.btn-submit { \n        min-width: 47%;\n        white-space: normal;\n    }\n    button.btn-cancel { \n        margin-left: 12px;\n    }\n    hr {\n        margin-top: 0px;\n    }\n  "],
                providers: [
                    FormService
                ]
            },] },
];
/**
 * @nocollapse
 */
OtpComponent.ctorParameters = function () { return [
    { type: FormBuilder, },
    { type: FormService, },
]; };
OtpComponent.propDecorators = {
    'validationMethodOtp': [{ type: Input },],
    'validationMsgOtp': [{ type: Input },],
    'onOtpSubmit': [{ type: Output },],
    'onOtpCancel': [{ type: Output },],
};
var AuthenComponent = (function () {
    function AuthenComponent() {
        this.onLogin = new EventEmitter();
        this.onOtp = new EventEmitter();
    }
    /**
     * @return {?}
     */
    AuthenComponent.prototype.ngOnInit = function () {
    };
    /**
     * @param {?} profile
     * @return {?}
     */
    AuthenComponent.prototype.onLoginSubmit = function (profile) {
        this.onLogin.emit(profile);
    };
    /**
     * @param {?} otp
     * @return {?}
     */
    AuthenComponent.prototype.onOtpSubmit = function (otp) {
        this.onOtp.emit(otp);
    };
    /**
     * @return {?}
     */
    AuthenComponent.prototype.onOtpCancel = function () {
        this.loginStatus = false;
    };
    return AuthenComponent;
}());
AuthenComponent.decorators = [
    { type: Component, args: [{
                selector: 'authen',
                template: "\n    <login *ngIf=\"!(loginStatus)\"\n        [validationMethodUsername]=\"validationMethodUsername\"\n        [validationMethodPassword]=\"validationMethodPassword\"\n        [validationMsgLogin]=\"validationMsgLogin\"\n        (onLoginSubmit)=\"onLoginSubmit($event)\"\n    ></login>\n    <otp *ngIf=\"loginStatus\"\n        [validationMethodOtp]=\"validationMethodOtp\"\n        [validationMsgOtp]=\"validationMsgOtp\"\n        (onOtpSubmit)=\"onLoginSubmit($event)\"\n        (onOtpCancel)=\"onLoginSubmit($event)\"   \n    ></otp>\n  ",
                styles: ["\n    .login-container { \n        background-color: #8ac33e;\n    }\n\n    .login-form {\n        margin-top: 40px;\n    }\n\n    .login-form .control-label {\n        color:#4d6513;\n    }\n\n    .login-container { \n        background-color: #8ac33e;\n    }\n\n    .login-form-head {\n        color: #ffffff;\n        font-size: 24px;\n    }\n\n    .login-form-head span {\n        padding-right: 5px;\n    }\n\n    .login-form-head hr {\n        margin-bottom: 10px;\n        margin-top: 0px;\n    }\n\n    .login-btn-submit {\n        background-color: #cceb6b;\n    }\n\n    .term-conditions {\n        color: #ffffff;\n        padding: 25px;\n    \n    }\n\n    .text-underline {\n        text-decoration: underline;\n    }\n\n    img#login-img { \n        float: left;\n        width: 15px;\n        padding: 0;\n        margin: 8px;\n        border:0;\n        margin-right:0;\n    }\n  "]
            },] },
];
/**
 * @nocollapse
 */
AuthenComponent.ctorParameters = function () { return []; };
AuthenComponent.propDecorators = {
    'loginStatus': [{ type: Input },],
    'validationMethodUsername': [{ type: Input },],
    'validationMethodPassword': [{ type: Input },],
    'validationMsgLogin': [{ type: Input },],
    'validationMethodOtp': [{ type: Input },],
    'validationMsgOtp': [{ type: Input },],
    'onLogin': [{ type: Output },],
    'onOtp': [{ type: Output },],
};
var LogoutComponent = (function () {
    function LogoutComponent() {
        this.alive = true;
    }
    /**
     * @return {?}
     */
    LogoutComponent.prototype.ngOnInit = function () {
        this.logout();
    };
    /**
     * @return {?}
     */
    LogoutComponent.prototype.logout = function () {
        // this.spinnerService.display(true);
        // this.authenService.logout()
        //   .takeWhile(alive => this.alive)
        //   .subscribe(data => {
        //     this.spinnerService.display(false);
        //     if (!data.error) {
        //       console.log('navigate')
        //       this.router.navigate(['/app/mynetwork/web/login']);
        //     }
        //   }, error => {
        //     this.spinnerService.display(false);
        //   })
    };
    /**
     * @return {?}
     */
    LogoutComponent.prototype.ngOnDestroy = function () {
        this.alive = false;
    };
    return LogoutComponent;
}());
LogoutComponent.decorators = [
    { type: Component, args: [{
                selector: 'ais-mynetwork-logout',
                template: "\n\n  ",
                styles: ["\n\n  "],
                providers: []
            },] },
];
/**
 * @nocollapse
 */
LogoutComponent.ctorParameters = function () { return []; };
var AuthenModule = (function () {
    function AuthenModule() {
    }
    return AuthenModule;
}());
AuthenModule.decorators = [
    { type: NgModule, args: [{
                imports: [
                    CommonModule,
                    ReactiveFormsModule
                ],
                declarations: [
                    LoginComponent,
                    OtpComponent,
                    AuthenComponent,
                    LogoutComponent
                ],
                providers: [],
                exports: [
                    LogoutComponent,
                    AuthenComponent
                ]
            },] },
];
/**
 * @nocollapse
 */
AuthenModule.ctorParameters = function () { return []; };
/**
 * Generated bundle index. Do not edit.
 */
export { AuthenModule, AuthenComponent as ɵd, LoginComponent as ɵa, LogoutComponent as ɵe, OtpComponent as ɵc, FormService as ɵb };
//# sourceMappingURL=ng-authentication.es5.js.map
