import { Component, EventEmitter, Injectable, Input, NgModule, Output } from '@angular/core';
import { CommonModule } from '@angular/common';
import { FormBuilder, ReactiveFormsModule } from '@angular/forms';
import 'rxjs/add/operator/takeWhile';

class FormService {
    /**
     * @param {?} formBuilder
     */
    constructor(formBuilder) {
        this.formBuilder = formBuilder;
    }
    /**
     * @param {?} controlsConfig
     * @return {?}
     */
    createForm(controlsConfig) {
        return this.formBuilder.group(controlsConfig);
    }
    /**
     * @param {?} formGroup
     * @param {?} formErrors
     * @param {?=} data
     * @return {?}
     */
    onValueChanged(formGroup, formErrors, data) {
        if (!formGroup) {
            return;
        }
        const /** @type {?} */ form = formGroup;
        for (const /** @type {?} */ field in formErrors) {
            // clear previous error message (if any)
            formErrors[field] = '';
            const /** @type {?} */ control = form.get(field);
            if (control && control.dirty && !control.valid) {
                const /** @type {?} */ messages = this.validationMessages[field];
                for (const /** @type {?} */ key in control.errors) {
                    formErrors[field] += messages[key] + ' ';
                }
            }
        }
    }
    /**
     * @param {?} validationMessages
     * @return {?}
     */
    setValidationMessages(validationMessages) {
        this.validationMessages = validationMessages;
    }
}
FormService.decorators = [
    { type: Injectable },
];
/**
 * @nocollapse
 */
FormService.ctorParameters = () => [
    { type: FormBuilder, },
];

class LoginComponent {
    /**
     * @param {?} formBuilder
     * @param {?} formService
     */
    constructor(formBuilder, formService) {
        this.formBuilder = formBuilder;
        this.formService = formService;
        this.onLoginSubmit = new EventEmitter();
        this.formErrors = {
            'username': '',
            'password': ''
        };
    }
    /**
     * @return {?}
     */
    ngOnInit() {
        this.createForm();
    }
    /**
     * @return {?}
     */
    onLogin() {
        const /** @type {?} */ formModel = this.loginForm.value;
        const /** @type {?} */ username = (formModel.username);
        const /** @type {?} */ password = (formModel.password);
        this.onLoginSubmit.emit({
            'username': username,
            'password': password
        });
    }
    /**
     * @return {?}
     */
    createForm() {
        console.log(this.validationMethodPassword);
        console.log(this.validationMethodUsername);
        console.log(this.validationMsgLogin);
        this.loginForm = this.formService.createForm({
            username: ['', this.validationMethodUsername],
            password: ['', this.validationMethodPassword]
        });
        this.formService.setValidationMessages(this.validationMsgLogin);
        this.loginForm.valueChanges
            .subscribe(data => this.formService.onValueChanged(this.loginForm, this.formErrors, data));
    }
}
LoginComponent.decorators = [
    { type: Component, args: [{
                selector: 'login',
                template: `
    <form id="loginForm" [formGroup]="loginForm" (ngSubmit)="onLogin()" class="form-horizontal">
      <div id="div-login-error" *ngIf="errorMessage" class="alert alert-danger" role="alert">
        {{ errorMessage }}
      </div>
      <hr>
      <div class="form-group">
        <label id="label-username" for="input-username" class="col-md-3 control-label ">ชื่อผู้ใช้งาน</label>
        <div class="col-md-9">
          <input id="input-username" type="text" formControlName="username" class="form-control  text-center"  placeholder="username">
          <span id="span-username-error" class="validate-msg" *ngIf="formErrors.username">
              {{ formErrors.username }}
            </span>
        </div>
      </div>
      <div class="form-group">
        <label id="label-password" for="input-password" class="col-md-3 control-label ">รหัสผ่าน</label>
        <div class="col-md-9">
          <input id="input-password" type="password" formControlName="password" class="form-control text-center" placeholder="password">
          <span id="span-password-error" class="validate-msg" *ngIf="formErrors.password">
              {{ formErrors.password }}
            </span>
        </div>
      </div>
      <div class="form-group">
        <label class="col-md-3 control-label"></label>
        <div class="col-md-9">
          <input id="btn-login" type="submit" class="btn btn-submit " value="LOG IN" [disabled]="!loginForm.valid">
        </div>
      </div>
    </form>
  `,
                styles: [`
    .control-label {
        color:#4d6513;
    }
    .btn{ 
        min-width: 100%;
        white-space: normal;
     }
    hr {
        margin-top: 0px;
    }
  `],
                providers: [
                    FormService
                ]
            },] },
];
/**
 * @nocollapse
 */
LoginComponent.ctorParameters = () => [
    { type: FormBuilder, },
    { type: FormService, },
];
LoginComponent.propDecorators = {
    'validationMethodUsername': [{ type: Input },],
    'validationMethodPassword': [{ type: Input },],
    'validationMsgLogin': [{ type: Input },],
    'onLoginSubmit': [{ type: Output },],
};

class OtpComponent {
    /**
     * @param {?} formBuilder
     * @param {?} formService
     */
    constructor(formBuilder, formService) {
        this.formBuilder = formBuilder;
        this.formService = formService;
        this.onOtpSubmit = new EventEmitter();
        this.onOtpCancel = new EventEmitter();
        this.formErrors = {
            'otp': ''
        };
        this.alive = true;
    }
    /**
     * @return {?}
     */
    ngOnInit() {
        this.createForm();
    }
    /**
     * @return {?}
     */
    onCheckOtp() {
        const /** @type {?} */ formModel = this.otpForm.value;
        const /** @type {?} */ otp = (formModel.otp);
        this.onOtpSubmit.emit(otp);
    }
    /**
     * @return {?}
     */
    onCancleOtp() {
    }
    /**
     * @return {?}
     */
    createForm() {
        this.otpForm = this.formService.createForm({
            otp: ['', this.validationMethodOtp]
        });
        this.formService.setValidationMessages(this.validationMsgOtp);
        this.otpForm.valueChanges
            .subscribe(data => this.formService.onValueChanged(this.otpForm, this.formErrors, data));
    }
}
OtpComponent.decorators = [
    { type: Component, args: [{
                selector: 'otp',
                template: `
    <form id="otpform" class="form-horizontal" [formGroup]="otpForm" (ngSubmit)="onCheckOtp()">
        <div id="div-otp-error" *ngIf="errorMessage" class="alert alert-danger" role="alert">
            {{ errorMessage }}
        </div>
        <hr>
        <div class="form-group">
            <div class="col-md-offset-3 col-md-9">
                <p class="validate-msg">กรุณาใส่รหัสผ่านที่ได้รับทาง SMS เพื่อเข้าสู่ระบบ</p>
            </div>
            <label id="label-otp" for="input-otp" class="col-md-3 control-label">OTP</label>
            <div class="col-md-9">
                <input id="input-otp" type="text" formControlName="otp" class="form-control text-center" placeholder="OTP" >
                <span id="span-otp-error" class="validate-msg" *ngIf="formErrors.otp">{{formErrors.otp}}</span>
            </div>
        </div>
        <div class="form-group">
            <div class="col-md-offset-3 col-md-9">
                <button id="btn-otp-ok" type="submit" class="btn btn-submit" data-toggle="modal" data-target=".bs-example-modal-sm" [disabled]="!otpForm.valid">OK</button>
                <button id="btn-otp-cancel" type="button" class="btn btn-cancel" (click)="onCancleOtp()">Cancel</button>
            </div>
        </div>
    </form>
  `,
                styles: [`
    .control-label {
        color:#4d6513;
    }
    button.btn.btn-cancel, button.btn.btn-submit { 
        min-width: 47%;
        white-space: normal;
    }
    button.btn-cancel { 
        margin-left: 12px;
    }
    hr {
        margin-top: 0px;
    }
  `],
                providers: [
                    FormService
                ]
            },] },
];
/**
 * @nocollapse
 */
OtpComponent.ctorParameters = () => [
    { type: FormBuilder, },
    { type: FormService, },
];
OtpComponent.propDecorators = {
    'validationMethodOtp': [{ type: Input },],
    'validationMsgOtp': [{ type: Input },],
    'onOtpSubmit': [{ type: Output },],
    'onOtpCancel': [{ type: Output },],
};

class AuthenComponent {
    constructor() {
        this.onLogin = new EventEmitter();
        this.onOtp = new EventEmitter();
    }
    /**
     * @return {?}
     */
    ngOnInit() {
    }
    /**
     * @param {?} profile
     * @return {?}
     */
    onLoginSubmit(profile) {
        this.onLogin.emit(profile);
    }
    /**
     * @param {?} otp
     * @return {?}
     */
    onOtpSubmit(otp) {
        this.onOtp.emit(otp);
    }
    /**
     * @return {?}
     */
    onOtpCancel() {
        this.loginStatus = false;
    }
}
AuthenComponent.decorators = [
    { type: Component, args: [{
                selector: 'authen',
                template: `
    <login *ngIf="!(loginStatus)"
        [validationMethodUsername]="validationMethodUsername"
        [validationMethodPassword]="validationMethodPassword"
        [validationMsgLogin]="validationMsgLogin"
        (onLoginSubmit)="onLoginSubmit($event)"
    ></login>
    <otp *ngIf="loginStatus"
        [validationMethodOtp]="validationMethodOtp"
        [validationMsgOtp]="validationMsgOtp"
        (onOtpSubmit)="onLoginSubmit($event)"
        (onOtpCancel)="onLoginSubmit($event)"   
    ></otp>
  `,
                styles: [`
    .login-container { 
        background-color: #8ac33e;
    }

    .login-form {
        margin-top: 40px;
    }

    .login-form .control-label {
        color:#4d6513;
    }

    .login-container { 
        background-color: #8ac33e;
    }

    .login-form-head {
        color: #ffffff;
        font-size: 24px;
    }

    .login-form-head span {
        padding-right: 5px;
    }

    .login-form-head hr {
        margin-bottom: 10px;
        margin-top: 0px;
    }

    .login-btn-submit {
        background-color: #cceb6b;
    }

    .term-conditions {
        color: #ffffff;
        padding: 25px;
    
    }

    .text-underline {
        text-decoration: underline;
    }

    img#login-img { 
        float: left;
        width: 15px;
        padding: 0;
        margin: 8px;
        border:0;
        margin-right:0;
    }
  `]
            },] },
];
/**
 * @nocollapse
 */
AuthenComponent.ctorParameters = () => [];
AuthenComponent.propDecorators = {
    'loginStatus': [{ type: Input },],
    'validationMethodUsername': [{ type: Input },],
    'validationMethodPassword': [{ type: Input },],
    'validationMsgLogin': [{ type: Input },],
    'validationMethodOtp': [{ type: Input },],
    'validationMsgOtp': [{ type: Input },],
    'onLogin': [{ type: Output },],
    'onOtp': [{ type: Output },],
};

class LogoutComponent {
    constructor() {
        this.alive = true;
    }
    /**
     * @return {?}
     */
    ngOnInit() {
        this.logout();
    }
    /**
     * @return {?}
     */
    logout() {
        // this.spinnerService.display(true);
        // this.authenService.logout()
        //   .takeWhile(alive => this.alive)
        //   .subscribe(data => {
        //     this.spinnerService.display(false);
        //     if (!data.error) {
        //       console.log('navigate')
        //       this.router.navigate(['/app/mynetwork/web/login']);
        //     }
        //   }, error => {
        //     this.spinnerService.display(false);
        //   })
    }
    /**
     * @return {?}
     */
    ngOnDestroy() {
        this.alive = false;
    }
}
LogoutComponent.decorators = [
    { type: Component, args: [{
                selector: 'ais-mynetwork-logout',
                template: `

  `,
                styles: [`

  `],
                providers: []
            },] },
];
/**
 * @nocollapse
 */
LogoutComponent.ctorParameters = () => [];

class AuthenModule {
}
AuthenModule.decorators = [
    { type: NgModule, args: [{
                imports: [
                    CommonModule,
                    ReactiveFormsModule
                ],
                declarations: [
                    LoginComponent,
                    OtpComponent,
                    AuthenComponent,
                    LogoutComponent
                ],
                providers: [],
                exports: [
                    LogoutComponent,
                    AuthenComponent
                ]
            },] },
];
/**
 * @nocollapse
 */
AuthenModule.ctorParameters = () => [];

/**
 * Generated bundle index. Do not edit.
 */

export { AuthenModule, AuthenComponent as ɵd, LoginComponent as ɵa, LogoutComponent as ɵe, OtpComponent as ɵc, FormService as ɵb };
//# sourceMappingURL=ng-authentication.js.map
